@@ -86,7 +86,7 @@ exports.report = function (req, res) {
     };
     //var type = req.param("type");
     //req.logger.info(type);
-    res.ireport("report1.jasper", "word", datas, parameters);
+    res.ireport("report1.jrxml", "word", datas, parameters);
 }
 
 exports.userinfo = function (req, res) {
